@@ -195,6 +195,8 @@ class Runner(Session):
         :return:
         """
         for other in job["dependencies"]:
+            if "artifacts_file" not in other:  # other job did not save any artifacts
+                continue
             trace.writeline("Fetching artifacts from {}..".format(other["name"]))
             url = self.api("jobs/{}/artifacts".format(other["id"]))
             resp = self.get(url,
